==> qtmultimedia-everywhere-src-5.10.1.tar.xz: qtmultimedia-everywhere-src-5.10.1/src/plugins/qnx/mediaplayer/mmrendereraudiorolecontrol.h <==
/****************************************************************************
**
** Copyright (C) 2017 QNX Software Systems. All rights reserved.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef MMRENDERERAUDIOROLECONTROL_H
#define MMRENDERERAUDIOROLECONTROL_H

#include <qaudiorolecontrol.h>

QT_BEGIN_NAMESPACE

class MmRendererAudioRoleControl : public QAudioRoleControl
{
    Q_OBJECT
public:
    explicit MmRendererAudioRoleControl(QObject *parent = 0);

    QAudio::Role audioRole() const Q_DECL_OVERRIDE;
    void setAudioRole(QAudio::Role role) Q_DECL_OVERRIDE;

    QList<QAudio::Role> supportedAudioRoles() const Q_DECL_OVERRIDE;

private:
    QAudio::Role m_role;
};

QT_END_NAMESPACE

#endif

==> qtmultimedia-everywhere-src-5.12.1.tar.xz: qtmultimedia-everywhere-src-5.12.1/src/plugins/qnx/mediaplayer/mmrendereraudiorolecontrol.h <==
/****************************************************************************
**
** Copyright (C) 2017 QNX Software Systems. All rights reserved.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef MMRENDERERAUDIOROLECONTROL_H
#define MMRENDERERAUDIOROLECONTROL_H

#include <qaudiorolecontrol.h>

QT_BEGIN_NAMESPACE

class MmRendererAudioRoleControl : public QAudioRoleControl
{
    Q_OBJECT
public:
    explicit MmRendererAudioRoleControl(QObject *parent = 0);

    QAudio::Role audioRole() const override;
    void setAudioRole(QAudio::Role role) override;

    QList<QAudio::Role> supportedAudioRoles() const override;

private:
    QAudio::Role m_role;
};

QT_END_NAMESPACE

#endif
